OC.L10N.register(
    "notes",
    {
    "Error" : "Hiba",
    "New note" : "Új jegyzet",
    "Notes" : "Jegyzetek",
    "Distraction-free notes and writing" : "Figyelemelterelés nélküli jegyzetelés és írás",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Mentetlen jegyzetek vannak. Az oldal elhagyásával a változások elvesznek.",
    "Settings" : "Beállítások",
    "Folder to store your notes" : "A jegyzetek tárolási mappája",
    "path to notes" : "megjegyzések útvonala",
    "File extension for new notes" : "Fájlkiterjesztés új jegyzetekhez",
    "All notes" : "Összes jegyzet",
    "Categories" : "Kategóriák",
    "Loading …" : "Töltés ...",
    "Today" : "Ma",
    "Yesterday" : "Tegnap",
    "This week" : "Ez a hét",
    "Last week" : "Előző hét",
    "This month" : "Ez a hónap",
    "Last month" : "Előző hónap",
    "Rename" : "Átnevezés",
    "Delete note" : "Jegyzet törlése",
    "Remove from favorites" : "Eltávolítás a kedvencekből",
    "Add to favorites" : "Hozzáadás a kedvencekhez",
    "Empty note" : "Üres jegyzet",
    "Write …" : "Írás ...",
    "Details" : "Részletek",
    "Edit" : "Szerkesztés",
    "Preview" : "Előnézet",
    "Set category" : "Kategória beállítása",
    "Category" : "Kategória",
    "Uncategorized" : "Kategorizálatlan",
    "Saving failed!" : "Mentés sikertelen!",
    "Last modified: {date}" : "Utoljára módosítva: {date}",
    "_%n word_::_%n words_" : ["%n szó","%n szó"],
    "Android app" : "Android alkalmazás",
    "iOS app" : "iOS alkalmazás",
    "Updating settings has failed." : "A beállítások frissítése sikertelen.",
    "Creating new note has failed." : "Új jegyzet létrehozása sikertelen."
},
"nplurals=2; plural=(n != 1);");
